# Personal Exposure and Health (or PEH) Data Model

## Introduction:
The PEH data model is the result of consolidation and harmonisation efforts in the Human Biomonitoring research field as well as an initiative to broaden the scope and support the inclusion of additional, relevant sources of information. Examples are project contexts and data from exposure related domains, such as environmental and geospatial observations.

The [PEH data model](https://github.com/eu-parc/parco-hbm/tree/main/linkml/schema) is defined using the [linkml](https://linkml.io/) modeling language.

## The data model and its purpose
The aim of this data model is to provide a domain specific structure for the data and metadata involved in typical human biomonitoring and personal exposure research projects, a terminology that supports expressing and annotating the (meta)data using harmonised vocabularies and a simple, more generic abstraction layer (at the "observed data records" level) that facilitates broader, cross-domain interoperability efforts.

In addition to adding semantic context and meaning to projects, studies and datasets that leverage it, the data model provides a stable ground for the development of supporting tools.

## Citing the PEH model
